@@ -9,7 +9,7 @@ from rich.table import Table
 console = Console(color_system="truecolor", highlight=False)
 
 table = Table()
-table.add_column("No.", style="white")
-table.add_column("Word You Input", style="yellow")
-table.add_column("Word Found", style="blue")
-table.add_column("Dictionary", style="white")
+table.add_column("No.", style = "white")
+table.add_column("Input Word", style = "yellow")
+table.add_column("Found Word", style = "blue")
+table.add_column("Dictionary", style = "green")
