@@ -12,7 +12,7 @@ logging.basicConfig(
     # filename=str(data / "dict.log"),
     # filemode="a",
     # format="%(asctime)s - %(pathname)s[line:%(lineno)d] - %(levelname)s: %(message)s",
-    format="%(asctime)s %(levelname)s %(filename)s %(message)s",
+    format="%(asctime)s %(levelname)s %(filename)s[%(lineno)d] %(message)s",
     datefmt="%Y-%m-%d %H:%M:%S",
     level=logging.INFO,
 )
