@@ -13,4 +13,4 @@ OP = [
     "DELETED",
 ]
 
-DICTS = ["CAMBRIDGE", "WEBSTER"]
+DICTS = ["CAMBRIDGE", "MERRIAM WEBSTER"]
